==> openshift-model-5.8.0-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseImageTriggerBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DeploymentCauseImageTriggerBuilder extends io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluentImpl<io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.DeploymentCauseImageTrigger,io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder>{
  public DeploymentCauseImageTriggerBuilder() {
    this(false);
  }
  public DeploymentCauseImageTriggerBuilder(java.lang.Boolean validationEnabled) {
    this(new DeploymentCauseImageTrigger(), validationEnabled);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DeploymentCauseImageTrigger(), validationEnabled);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent,io.fabric8.openshift.api.model.DeploymentCauseImageTrigger instance) {
    this(fluent, instance, false);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent,io.fabric8.openshift.api.model.DeploymentCauseImageTrigger instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFrom(instance.getFrom()); 
    this.validationEnabled = validationEnabled; 
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger instance) {
    this(instance,false);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFrom(instance.getFrom()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.DeploymentCauseImageTrigger build() {
    DeploymentCauseImageTrigger buildable = new DeploymentCauseImageTrigger(fluent.getFrom());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeploymentCauseImageTriggerBuilder that = (DeploymentCauseImageTriggerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/DeploymentCauseImageTriggerBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class DeploymentCauseImageTriggerBuilder extends io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluentImpl<io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.DeploymentCauseImageTrigger,io.fabric8.openshift.api.model.DeploymentCauseImageTriggerBuilder>{
  public DeploymentCauseImageTriggerBuilder() {
    this(false);
  }
  public DeploymentCauseImageTriggerBuilder(java.lang.Boolean validationEnabled) {
    this(new DeploymentCauseImageTrigger(), validationEnabled);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent) {
    this(fluent, false);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new DeploymentCauseImageTrigger(), validationEnabled);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent,io.fabric8.openshift.api.model.DeploymentCauseImageTrigger instance) {
    this(fluent, instance, false);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent,io.fabric8.openshift.api.model.DeploymentCauseImageTrigger instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withFrom(instance.getFrom()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger instance) {
    this(instance,false);
  }
  public DeploymentCauseImageTriggerBuilder(io.fabric8.openshift.api.model.DeploymentCauseImageTrigger instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withFrom(instance.getFrom()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.DeploymentCauseImageTriggerFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.DeploymentCauseImageTrigger build() {
    DeploymentCauseImageTrigger buildable = new DeploymentCauseImageTrigger(fluent.getFrom());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeploymentCauseImageTriggerBuilder that = (DeploymentCauseImageTriggerBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
